==> ui-react-1.1.484.tgz: package/esm/Frame/Frame.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
const _excluded = ["url", "src", "value", "startOptions", "endOptions", "IconMobile", "IconTablet", "IconLaptop", "IconDesktop", "iframeProps", "IFrameProps", "OptionProps", "OptionsProps", "OptionsWrapperProps", "WrapperProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { isEnvironment } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import IconElement from '../Icon';
import IconButtonElement from '../IconButton';
import LineElement from '../Line';
import TooltipElement from '../Tooltip';
import IFrameElement_ from '../IFrame';
import { staticClassName } from '../utils';
const IconMaterialSmartphone = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Smartphone",
    short_name: "Smartphone",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M7 23q-.825 0-1.412-.587Q5 21.825 5 21V3q0-.825.588-1.413Q6.175 1 7 1h10q.825 0 1.413.587Q19 2.175 19 3v18q0 .825-.587 1.413Q17.825 23 17 23Zm0-5h10V6H7Zm0 2v1h10v-1ZM7 4h10V3H7Zm0-1v1-1Zm0 18v-1 1Z"
  }));
});
const IconMaterialTabletMac = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "TabletMac",
    short_name: "TabletMac",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M5 23q-.825 0-1.413-.587Q3 21.825 3 21V3q0-.825.587-1.413Q4.175 1 5 1h14q.825 0 1.413.587Q21 2.175 21 3v18q0 .825-.587 1.413Q19.825 23 19 23Zm0-7h14V6H5Zm0 2v3h14v-3ZM5 4h14V3H5Zm0-1v1-1Zm0 18v-3 3Zm7-.5q.425 0 .713-.288.287-.287.287-.712t-.287-.712Q12.425 18.5 12 18.5t-.712.288Q11 19.075 11 19.5t.288.712q.287.288.712.288Z"
  }));
});
const IconMaterialComputer = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Computer",
    short_name: "Computer",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M4 18q-.825 0-1.412-.587Q2 16.825 2 16V5q0-.825.588-1.413Q3.175 3 4 3h16q.825 0 1.413.587Q22 4.175 22 5v11q0 .825-.587 1.413Q20.825 18 20 18Zm0-2h16V5H4v11Zm-2 5q-.425 0-.712-.288Q1 20.425 1 20t.288-.712Q1.575 19 2 19h20q.425 0 .712.288.288.287.288.712t-.288.712Q22.425 21 22 21Zm2-5V5v11Z"
  }));
});
const IconMaterialDesktopWindows = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "DesktopWindows",
    short_name: "DesktopWindows",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M9 22q-.425 0-.712-.288Q8 21.425 8 21t.288-.712Q8.575 20 9 20h1v-2H4q-.825 0-1.412-.587Q2 16.825 2 16V5q0-.825.588-1.413Q3.175 3 4 3h16q.825 0 1.413.587Q22 4.175 22 5v11q0 .825-.587 1.413Q20.825 18 20 18h-6v2h1q.425 0 .713.288.287.287.287.712t-.287.712Q15.425 22 15 22Zm-5-6h16V5H4v11Zm0 0V5v11Z"
  }));
});
const useStyle = styleMethod(theme => ({
  root: {
    position: 'relative',
    overflow: 'hidden'
  },
  options: {
    overflowX: 'auto',
    overflowY: 'hidden',
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(3, 'px')}`,
    '& > *': {
      flex: '0 0 auto'
    }
  },
  wrapper: {
    margin: '0 4px 24px',
    minHeight: '15vh',
    height: 0,
    border: `0.5px solid ${theme.palette.text.divider}`,
    borderRadius: theme.methods.shape.radius.value(2),
    boxShadow: theme.shadows.values.default[1],
    overflow: 'hidden',
    '&.amaui-Line-root': {
      width: 'calc(100% - 8px)'
    }
  },
  IFrame: {
    position: 'relative'
  },
  iframe: {
    width: '100%',
    height: '100%'
  }
}), {
  name: 'amaui-Frame'
});
const Frame = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiFrame?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const IconButton = React.useMemo(() => theme?.elements?.IconButton || IconButtonElement, [theme]);
  const Tooltip = React.useMemo(() => theme?.elements?.Tooltip || TooltipElement, [theme]);
  const IFrameElement = React.useMemo(() => theme?.elements?.IFrame || IFrameElement_, [theme]);
  const {
      url,
      src,
      value,
      startOptions,
      endOptions,
      IconMobile = IconMaterialSmartphone,
      IconTablet = IconMaterialTabletMac,
      IconLaptop = IconMaterialComputer,
      IconDesktop = IconMaterialDesktopWindows,
      iframeProps,
      IFrameProps,
      OptionProps,
      OptionsProps,
      OptionsWrapperProps,
      WrapperProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [responsive, setResponsive] = React.useState();
  const onResponsive = React.useCallback(value_ => {
    setResponsive(previous => {
      if (previous === value_) return '';
      return value_;
    });
  }, []);
  const responsiveOptions = [{
    name: 'Mobile',
    icon: IconMobile,
    disabled: isEnvironment('browser') && window.innerWidth < 375
  }, {
    name: 'Tablet',
    icon: IconTablet,
    disabled: isEnvironment('browser') && window.innerWidth < 768
  }, {
    name: 'Laptop',
    icon: IconLaptop,
    disabled: isEnvironment('browser') && window.innerWidth < 1440
  }, {
    name: 'Desktop',
    icon: IconDesktop,
    disabled: isEnvironment('browser') && window.innerWidth < 1920
  }];
  const WrapperStyle = {};
  if (responsive) {
    // iphone SE
    if (responsive === 'Mobile') {
      WrapperStyle.maxWidth = 375;
      WrapperStyle.maxHeight = 667;
    }

    // ipad mini
    if (responsive === 'Tablet') {
      WrapperStyle.maxWidth = 768;
      WrapperStyle.maxHeight = 1024;
    }

    // laptop
    if (responsive === 'Laptop') {
      WrapperStyle.maxWidth = 1440;
      WrapperStyle.maxHeight = 768;
    }

    // desktop
    if (responsive === 'Desktop') {
      WrapperStyle.maxWidth = 1920;
      WrapperStyle.maxHeight = 1080;
    }
  }
  const main = /*#__PURE__*/React.createElement(React.Fragment, null, children, value && !children && /*#__PURE__*/React.createElement(IFrameElement, {
    className: classNames([classes.IFrame]),
    WrapperProps: {
      align: 'center',
      justify: 'center'
    }
  }, value || children), (url || src) && !(value || children) && /*#__PURE__*/React.createElement("iframe", _extends({
    title: "frame",
    src: url || src
  }, iframeProps, {
    className: classNames([iframeProps?.className, classes.iframe])
  })));
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: ref,
    gap: 0,
    align: "center",
    flex: true,
    fullWidth: true,
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-root'], className, classes.root])
  }, other), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0.5,
    direction: "row",
    align: "center",
    justify: {
      xxs: 'flex-start',
      xs: 'flex-start',
      default: 'flex-end'
    },
    fullWidth: true
  }, OptionsWrapperProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-options-wrapper'], OptionsWrapperProps?.className])
  }), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0.4,
    direction: "row",
    align: "center",
    justify: "flex-end"
  }, OptionsProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-options'], OptionsProps?.className, classes.options])
  }), startOptions, responsiveOptions.map((item, index) => /*#__PURE__*/React.createElement(Tooltip, {
    key: index,
    label: item.name
  }, /*#__PURE__*/React.createElement(IconButton, _extends({
    size: "small",
    selected: item.name === responsive,
    onClick: () => onResponsive(item.name),
    disabled: item.disabled
  }, OptionProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-option'], OptionProps?.className])
  }), /*#__PURE__*/React.createElement(item.icon, null)))), endOptions)), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0,
    align: "center",
    flex: true,
    fullWidth: true
  }, WrapperProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-wrapper'], WrapperProps?.className, classes.wrapper]),
    style: _objectSpread(_objectSpread({}, WrapperStyle), WrapperProps?.style)
  }), main));
});
Frame.displayName = 'amaui-Frame';
export default Frame;

==> ui-react-1.1.530.tgz: package/esm/Frame/Frame.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
const _excluded = ["url", "src", "value", "startOptions", "endOptions", "IconMobile", "IconTablet", "IconLaptop", "IconDesktop", "iframeProps", "IFrameProps", "OptionProps", "OptionsProps", "OptionsWrapperProps", "WrapperProps", "className", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { isEnvironment } from '@amaui/utils';
import { classNames, style as styleMethod, useAmauiTheme } from '@amaui/style-react';
import IconElement from '../Icon';
import IconButtonElement from '../IconButton';
import LineElement from '../Line';
import TooltipElement from '../Tooltip';
import IFrameElement_ from '../IFrame';
import { staticClassName } from '../utils';
const IconMaterialSmartphone = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Smartphone",
    short_name: "Smartphone",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M7 23q-.825 0-1.412-.587Q5 21.825 5 21V3q0-.825.588-1.413Q6.175 1 7 1h10q.825 0 1.413.587Q19 2.175 19 3v18q0 .825-.587 1.413Q17.825 23 17 23Zm0-5h10V6H7Zm0 2v1h10v-1ZM7 4h10V3H7Zm0-1v1-1Zm0 18v-1 1Z"
  }));
});
const IconMaterialTabletMac = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "TabletMac",
    short_name: "TabletMac",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M5 23q-.825 0-1.413-.587Q3 21.825 3 21V3q0-.825.587-1.413Q4.175 1 5 1h14q.825 0 1.413.587Q21 2.175 21 3v18q0 .825-.587 1.413Q19.825 23 19 23Zm0-7h14V6H5Zm0 2v3h14v-3ZM5 4h14V3H5Zm0-1v1-1Zm0 18v-3 3Zm7-.5q.425 0 .713-.288.287-.287.287-.712t-.287-.712Q12.425 18.5 12 18.5t-.712.288Q11 19.075 11 19.5t.288.712q.287.288.712.288Z"
  }));
});
const IconMaterialComputer = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "Computer",
    short_name: "Computer",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M4 18q-.825 0-1.412-.587Q2 16.825 2 16V5q0-.825.588-1.413Q3.175 3 4 3h16q.825 0 1.413.587Q22 4.175 22 5v11q0 .825-.587 1.413Q20.825 18 20 18Zm0-2h16V5H4v11Zm-2 5q-.425 0-.712-.288Q1 20.425 1 20t.288-.712Q1.575 19 2 19h20q.425 0 .712.288.288.287.288.712t-.288.712Q22.425 21 22 21Zm2-5V5v11Z"
  }));
});
const IconMaterialDesktopWindows = /*#__PURE__*/React.forwardRef((props, ref) => {
  return /*#__PURE__*/React.createElement(IconElement, _extends({
    ref: ref,
    name: "DesktopWindows",
    short_name: "DesktopWindows",
    viewBox: "0 0 24 24"
  }, props), /*#__PURE__*/React.createElement("path", {
    d: "M9 22q-.425 0-.712-.288Q8 21.425 8 21t.288-.712Q8.575 20 9 20h1v-2H4q-.825 0-1.412-.587Q2 16.825 2 16V5q0-.825.588-1.413Q3.175 3 4 3h16q.825 0 1.413.587Q22 4.175 22 5v11q0 .825-.587 1.413Q20.825 18 20 18h-6v2h1q.425 0 .713.288.287.287.287.712t-.287.712Q15.425 22 15 22Zm-5-6h16V5H4v11Zm0 0V5v11Z"
  }));
});
const useStyle = styleMethod(theme => ({
  root: {
    position: 'relative',
    overflow: 'hidden'
  },
  options: {
    overflowX: 'auto',
    overflowY: 'hidden',
    padding: `${theme.methods.space.value(1.5, 'px')} ${theme.methods.space.value(3, 'px')}`,
    '& > *': {
      flex: '0 0 auto'
    }
  },
  wrapper: {
    margin: '0 4px 24px',
    minHeight: '15vh',
    height: 0,
    border: `0.5px solid ${theme.palette.text.divider}`,
    borderRadius: theme.methods.shape.radius.value(2),
    boxShadow: theme.shadows.values.default[1],
    overflow: 'hidden',
    '&.amaui-Line-root': {
      width: 'calc(100% - 8px)'
    }
  },
  IFrame: {
    position: 'relative'
  },
  iframe: {
    width: '100%',
    height: '100%'
  }
}), {
  name: 'amaui-Frame'
});
const Frame = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiFrame?.props?.default), props_), [props_]);
  const Line = React.useMemo(() => theme?.elements?.Line || LineElement, [theme]);
  const IconButton = React.useMemo(() => theme?.elements?.IconButton || IconButtonElement, [theme]);
  const Tooltip = React.useMemo(() => theme?.elements?.Tooltip || TooltipElement, [theme]);
  const IFrameElement = React.useMemo(() => theme?.elements?.IFrame || IFrameElement_, [theme]);
  const {
      url,
      src,
      value,
      startOptions,
      endOptions,
      IconMobile = IconMaterialSmartphone,
      IconTablet = IconMaterialTabletMac,
      IconLaptop = IconMaterialComputer,
      IconDesktop = IconMaterialDesktopWindows,
      iframeProps,
      IFrameProps,
      OptionProps,
      OptionsProps,
      OptionsWrapperProps,
      WrapperProps,
      className,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const {
    classes
  } = useStyle();
  const [responsive, setResponsive] = React.useState();
  const onResponsive = React.useCallback(value_ => {
    setResponsive(previous => {
      if (previous === value_) return '';
      return value_;
    });
  }, []);
  const responsiveOptions = [{
    name: 'Mobile',
    icon: IconMobile,
    disabled: isEnvironment('browser') && window.innerWidth < 375
  }, {
    name: 'Tablet',
    icon: IconTablet,
    disabled: isEnvironment('browser') && window.innerWidth < 768
  }, {
    name: 'Laptop',
    icon: IconLaptop,
    disabled: isEnvironment('browser') && window.innerWidth < 1440
  }, {
    name: 'Desktop',
    icon: IconDesktop,
    disabled: isEnvironment('browser') && window.innerWidth < 1920
  }];
  const WrapperStyle = {};
  if (responsive) {
    // iphone SE
    if (responsive === 'Mobile') {
      WrapperStyle.maxWidth = 375;
      WrapperStyle.maxHeight = 667;
    }

    // ipad mini
    if (responsive === 'Tablet') {
      WrapperStyle.maxWidth = 768;
      WrapperStyle.maxHeight = 1024;
    }

    // laptop
    if (responsive === 'Laptop') {
      WrapperStyle.maxWidth = 1440;
      WrapperStyle.maxHeight = 768;
    }

    // desktop
    if (responsive === 'Desktop') {
      WrapperStyle.maxWidth = 1920;
      WrapperStyle.maxHeight = 1080;
    }
  }
  const main = React.useMemo(() => {
    return /*#__PURE__*/React.createElement(React.Fragment, null, children, value && !children && /*#__PURE__*/React.createElement(IFrameElement, {
      className: classNames([classes.IFrame]),
      WrapperProps: {
        align: 'center',
        justify: 'center'
      }
    }, value || children), (url || src) && !(value || children) && /*#__PURE__*/React.createElement("iframe", _extends({
      title: "frame",
      src: url || src
    }, iframeProps, {
      className: classNames([iframeProps?.className, classes.iframe])
    })));
  }, [url, src, value, children]);
  return /*#__PURE__*/React.createElement(Line, _extends({
    ref: ref,
    gap: 0,
    align: "center",
    flex: true,
    fullWidth: true,
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-root'], className, classes.root])
  }, other), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0.5,
    direction: "row",
    align: "center",
    justify: {
      xxs: 'flex-start',
      xs: 'flex-start',
      default: 'flex-end'
    },
    fullWidth: true
  }, OptionsWrapperProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-options-wrapper'], OptionsWrapperProps?.className])
  }), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0.4,
    direction: "row",
    align: "center",
    justify: "flex-end"
  }, OptionsProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-options'], OptionsProps?.className, classes.options])
  }), startOptions, responsiveOptions.map((item, index) => /*#__PURE__*/React.createElement(Tooltip, {
    key: index,
    label: item.name
  }, /*#__PURE__*/React.createElement(IconButton, _extends({
    size: "small",
    selected: item.name === responsive,
    onClick: () => onResponsive(item.name),
    disabled: item.disabled
  }, OptionProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-option'], OptionProps?.className])
  }), /*#__PURE__*/React.createElement(item.icon, null)))), endOptions)), /*#__PURE__*/React.createElement(Line, _extends({
    gap: 0,
    align: "center",
    flex: true,
    fullWidth: true
  }, WrapperProps, {
    className: classNames([staticClassName('Frame', theme) && ['amaui-Frame-wrapper'], WrapperProps?.className, classes.wrapper]),
    style: _objectSpread(_objectSpread({}, WrapperStyle), WrapperProps?.style)
  }), main));
});
Frame.displayName = 'amaui-Frame';
export default Frame;
